@@ -3,12 +3,12 @@ package Mastodon::Entity::Instance;
 use strict;
 use warnings;
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use Moo;
 with 'Mastodon::Role::Entity';
 
-use Types::Standard qw( Bool Str );
+use Types::Standard qw( Str );
 use Mastodon::Types qw( URI );
 
 has email       => ( is => 'ro', isa => Str, );
