@@ -3,7 +3,7 @@ package Mastodon::Role::UserAgent;
 use strict;
 use warnings;
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use v5.10.0;
 use Moo::Role;
@@ -13,8 +13,24 @@ my $log = Log::Any->get_logger( category => 'Mastodon' );
 
 use URI::QueryParam;
 use List::Util qw( any );
-use Types::Standard qw( Undef Str Num ArrayRef HashRef Dict slurpy );
-use Mastodon::Types qw( URI Instance UserAgent to_Entity );
+use Types::Standard qw(
+    ArrayRef
+    Dict
+    HashRef
+    Maybe
+    Num
+    Optional
+    Str
+    Undef
+    slurpy
+);
+use Mastodon::Types qw(
+    HTTPResponse
+    Instance
+    URI
+    UserAgent
+    to_Entity
+);
 use Type::Params qw( compile );
 use Carp;
 
@@ -42,11 +58,17 @@ has user_agent => (
   is => 'ro',
   isa => UserAgent,
   default => sub {
-    require LWP::UserAgent;
-    LWP::UserAgent->new;
+    require HTTP::Thin;
+    HTTP::Thin->new;
   },
 );
 
+has latest_response => (
+    is => 'ro',
+    isa => Maybe[HTTPResponse],
+    init_args => undef,
+);
+
 sub authorization_url {
   my $self = shift;
 
@@ -56,17 +78,17 @@ sub authorization_url {
     );
   }
 
-  state $check = compile( slurpy Dict[
-    instance => Instance->plus_coercions( Undef, sub { $self->instance } ),
-  ]);
-
-  use URI::QueryParam;
+  state $check = compile( slurpy Dict [ access_code => Optional [Instance] ] );
   my ($params) = $check->(@_);
+
+  $params->{instance} //= $self->instance;
+
   my $uri = URI->new('/oauth/authorize')->abs($params->{instance}->uri);
   $uri->query_param(redirect_uri => $self->redirect_uri);
   $uri->query_param(response_type => 'code');
   $uri->query_param(client_id => $self->client_id);
   $uri->query_param(scope => join q{ }, sort(@{$self->scopes}));
+
   return $uri;
 }
 
@@ -75,24 +97,6 @@ sub patch  { shift->_request( patch  => shift, data   => shift, @_ ) }
 sub get    { shift->_request( get    => shift, params => shift, @_ ) }
 sub delete { shift->_request( delete => shift, params => shift, @_ ) }
 
-sub _build_url {
-  my $self = shift;
-
-  state $check = compile(
-    URI->plus_coercions(
-      Str, sub {
-        s{(?:^/|/$)}{}g;
-        require URI;
-        my $api = (m{^/?oauth/}) ? q{} : 'api/v' . $self->api_version . '/';
-        URI->new(join '/', $self->instance->uri, $api . $_);
-      },
-    )
-  );
-
-  my ($url) = $check->(@_);
-  return $url;
-}
-
 sub _request {
   my $self   = shift;
   my $method = shift;
@@ -137,6 +141,9 @@ sub _request {
     use JSON::MaybeXS qw( decode_json );
     use Encode qw( encode );
 
+    # We want to be able to set it, but do not want the user to do so
+    $self->{latest_response} = $response;
+
     die $response->status_line unless $response->is_success;
 
     my $payload = decode_json encode('utf8', $response->decoded_content);
@@ -188,7 +195,12 @@ sub _prepare_params {
   my ($self, $url, $params) = @_;
   $params //= {};
 
-  $url = $self->_build_url($url) unless ref $url eq 'URI';
+  croak 'Cannot make a request without a URL' unless $url;
+
+  unless (ref $url eq 'URI') {
+    my $base = $url =~ m{^/oauth/} ? '/' : '/api/v' . $self->api_version . '/';
+    $url = URI->new( $self->instance->uri . $base . $url );
+  }
 
   # Adjust query param format to be Ruby-compliant
   foreach my $key (keys %{$params}) {
