@@ -3,7 +3,7 @@ package Mastodon::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.015';
+our $VERSION = '0.016';
 
 use Type::Library -base;
 
@@ -32,6 +32,8 @@ coerce 'URI', from Str, via {
 
 class_type 'DateTime', { class => 'DateTime' };
 
+class_type 'HTTPResponse', { class => 'HTTP::Response' };
+
 coerce 'DateTime',
   from Num,
     via { 'DateTime'->from_epoch( epoch => $_ ) }
@@ -65,7 +67,7 @@ coerce 'Image',
     require MIME::Base64;
     my $type = lc Image::Info::image_type( $file->stringify )->{file_type};
     my $img = "data:image/$type;base64,"
-      . MIME::Base64::encode_base64( $file->slurp );
+      . MIME::Base64::encode_base64( $file->slurp_raw );
     return $img;
   };
 
